@@ -10,22 +10,42 @@ from .exceptions import GetBalanceError, GetTaskError, GetResultError, UnknownRe
 from .clientOptions import ClientOptions
 from .requests import *
 from .GetResultTimeouts import *
+from .utils import parseVersion
 
 
 _instance_config = (
-    ((RecaptchaV2ProxylessRequest, RecaptchaV2Request), getRecaptchaV2Timeouts),
-    ((RecaptchaV2EnterpriseProxylessRequest, RecaptchaV2EnterpriseRequest), getRecaptchaV2EnterpriseTimeouts),
+    ((RecaptchaV2Request,), getRecaptchaV2Timeouts),
+    ((RecaptchaV2EnterpriseRequest,), getRecaptchaV2EnterpriseTimeouts),
     ((RecaptchaV3ProxylessRequest), getRecaptchaV3Timeouts),
     ((ImageToTextRequest), getImage2TextTimeouts),
-    ((FuncaptchaProxylessRequest, FuncaptchaRequest), getFuncaptchaTimeouts),
-    ((HcaptchaProxylessRequest, HcaptchaRequest), getHcaptchaTimeouts),
-    ((GeetestProxylessRequest, GeetestRequest), getGeetestTimeouts)
+    ((FuncaptchaRequest,), getFuncaptchaTimeouts),
+    ((HcaptchaRequest,), getHcaptchaTimeouts),
+    ((GeetestRequest,), getGeetestTimeouts),
+    ((TurnstileRequest,), getTurnstileTimeouts),
+    ((RecaptchaComplexImageTaskRequest, HcaptchaComplexImageTaskRequest, 
+      FunCaptchaComplexImageTaskRequest), getImage2TextTimeouts),
+    ((DataDomeCustomTaskRequest,), getDatadomeTimeouts),
+    ((TenDiCustomTaskRequest,), getTenDiTimeouts),
+    ((BasiliskCustomTaskRequest,), getBasiliskTimeouts),
+    ((AmazonWafRequest,), getAmazonWafTimeouts),
+    ((BinanceTaskRequest,), getBinanceTimeouts),
+    ((ImpervaCustomTaskRequest,), getImpervaTimeouts),
+    ((RecognitionComplexImageTaskRequest), getCITTimeouts),
+    ((MTCaptchaRequest), getImage2TextTimeouts),
+    ((YidunRequest), getImage2TextTimeouts),
 )
 
 
 class CapMonsterClient:
-    def __init__(self, options: ClientOptions) -> None:
+    def __init__(self, 
+                 options: ClientOptions) -> None:
         self.options = options
+        self._headers = {'User-Agent': 
+                         f'Zennolab.CapMonsterCloud.Client.Python/{parseVersion()}'}
+    
+    @property
+    def headers(self):
+        return self._headers
 
     async def get_balance(self) -> Dict[str, Union[int, float, str]]:
         body = {
@@ -43,12 +63,28 @@ class CapMonsterClient:
                 return result
 
 
-    async def solve_captcha(self, request: Union[RecaptchaV2EnterpriseProxylessRequest,
-                                                 RecaptchaV2EnterpriseRequest, RecaptchaV2Request,
-                                                 RecaptchaV2ProxylessRequest, RecaptchaV3ProxylessRequest,
-                                                 ImageToTextRequest, FuncaptchaProxylessRequest,
-                                                 FuncaptchaRequest, HcaptchaRequest, HcaptchaProxylessRequest,
-                                                 GeetestProxylessRequest, GeetestRequest]) -> Dict[str, str]:
+    async def solve_captcha(self, request: Union[
+                                                 RecaptchaV2EnterpriseRequest, 
+                                                 RecaptchaV2Request,
+                                                 RecaptchaV3ProxylessRequest,
+                                                 RecaptchaComplexImageTaskRequest,
+                                                 ImageToTextRequest, 
+                                                 FuncaptchaRequest,
+                                                 FunCaptchaComplexImageTaskRequest,
+                                                 HcaptchaRequest,
+                                                 HcaptchaComplexImageTaskRequest,
+                                                 GeetestRequest,
+                                                 DataDomeCustomTaskRequest,
+                                                 TenDiCustomTaskRequest,
+                                                 BasiliskCustomTaskRequest,
+                                                 AmazonWafRequest,
+                                                 BinanceTaskRequest,
+                                                 ImpervaCustomTaskRequest,
+                                                 TurnstileRequest,
+                                                 RecognitionComplexImageTaskRequest,
+                                                 MTCaptchaRequest,
+                                                 YidunRequest],
+                            ) -> Dict[str, str]:
         '''
         Non-blocking method for captcha solving. 
 
@@ -62,13 +98,27 @@ class CapMonsterClient:
         raise UnknownRequestInstanceError(f'Unknown request instance "{type(request)}", ' \
                                             f'expected that request will belong next instances: {rs_all}')
         
-    async def _solve(self, request: Union[RecaptchaV2EnterpriseProxylessRequest,
-                                          RecaptchaV2EnterpriseRequest, RecaptchaV2Request,
-                                          RecaptchaV2ProxylessRequest, RecaptchaV3ProxylessRequest,
-                                          ImageToTextRequest, FuncaptchaProxylessRequest,
-                                          FuncaptchaRequest, HcaptchaRequest, HcaptchaProxylessRequest,
-                                          GeetestProxylessRequest, GeetestRequest],
-                           timeouts: GetResultTimeouts) -> Dict[str, str]:
+    async def _solve(self, request: Union[
+                                          RecaptchaV2EnterpriseRequest, 
+                                          RecaptchaV2Request,
+                                          RecaptchaV3ProxylessRequest,
+                                          RecaptchaComplexImageTaskRequest,
+                                          ImageToTextRequest, 
+                                          FuncaptchaRequest,
+                                          FunCaptchaComplexImageTaskRequest,
+                                          HcaptchaRequest,
+                                          HcaptchaComplexImageTaskRequest,
+                                          GeetestRequest,
+                                          DataDomeCustomTaskRequest,
+                                          TenDiCustomTaskRequest,
+                                          BasiliskCustomTaskRequest,
+                                          AmazonWafRequest,
+                                          BinanceTaskRequest,
+                                          ImpervaCustomTaskRequest,
+                                          TurnstileRequest,
+                                          RecognitionComplexImageTaskRequest],
+                           timeouts: GetResultTimeouts,
+                           ) -> Dict[str, str]:
 
         getTaskResponse = await self._createTask(request)
         if getTaskResponse.get('errorId') != 0:
@@ -109,7 +159,8 @@ class CapMonsterClient:
         async with aiohttp.ClientSession() as session:
             async with session.post(url=self.options.service_url + '/getTaskResult',
                                     json=body, 
-                                    timeout=aiohttp.ClientTimeout(total=self.options.client_timeout)) as resp:
+                                    timeout=aiohttp.ClientTimeout(total=self.options.client_timeout),
+                                    headers=self.headers) as resp:
                 if resp.status != 200:
                     if resp.status == 500:
                         return {'errorId': 0, 'status': 'processing'}
@@ -128,7 +179,8 @@ class CapMonsterClient:
         async with aiohttp.ClientSession() as session:
             async with session.post(url=self.options.service_url + '/createTask',
                                     json=body, 
-                                    timeout=aiohttp.ClientTimeout(total=self.options.client_timeout)) as resp:
+                                    timeout=aiohttp.ClientTimeout(total=self.options.client_timeout),
+                                    headers=self.headers) as resp:
                 if resp.status != 200:
                     raise HTTPException(f'Cannot create task. Status code: {resp.status}.')
                 else:
